==> spirit_hub-0.0.1.0.tar.gz: spirit_hub-0.0.1.0/app/controllers/spirit_hub/favorites_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class FavoritesController < ApplicationController
    include Datatablable

    before_action :find_models, only: %i[index sort]

    def index
      skip_authorization
      skip_policy_scope

      calculate_counts

      respond_to(&:html)
    end

    def sort
      skip_authorization
      skip_policy_scope

      render partial: 'spirit_hub/favorites/table'
    end

    def remove
      skip_authorization
      skip_policy_scope

      @favorite = Tagset.find(params[:id])

      if Favorite.where(user: @user, tagset: @favorite).destroy_all
        set_user_favorites
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de l\'ajout au favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def calculate_counts
      @counts = @user.dashboard_counts
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      @user_favorites = Favorite.where(user_id: @user.id).pluck(:tagset_id).flatten.uniq.compact
      scope = Tagset.where(:id.in => @user_favorites)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end

==> spirit_hub-0.0.1.5.tar.gz: spirit_hub-0.0.1.5/app/controllers/spirit_hub/favorites_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class FavoritesController < ApplicationController
    include Datatablable

    before_action :find_models, only: %i[index sort]

    def index
      skip_authorization
      skip_policy_scope

      calculate_counts

      respond_to(&:html)
    end

    def sort
      skip_authorization
      skip_policy_scope

      render partial: 'spirit_hub/favorites/table'
    end

    def remove
      skip_authorization
      skip_policy_scope

      @favorite = Tagset.find(params[:id])

      if Favorite.where(user: @user, tagset: @favorite).destroy_all
        set_user_favorites
        flash.now[:notice] = 'Supprimé des favoris'

        render turbo_stream: [
          turbo_stream.remove("tagset_#{params[:id]}"),
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
          turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -1 })
        ]
      else
        flash.now[:alert] = 'Erreur lors de la suppression du favoris'

        render turbo_stream: [
          turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
        ]
      end
    end

    def calculate_counts
      @counts = @user.dashboard_counts
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      @user_favorites = Favorite.where(user_id: @user.id).pluck(:tagset_id).flatten.uniq.compact
      scope = Tagset.where(:id.in => @user_favorites)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end
